#!/usr/bin/env node
var minimist = require('minimist');
var archy = require('archy');
var extend = require('xtend');
var cli_1 = require('../utils/cli');
var config_1 = require('../utils/config');
var dependencies_1 = require('../lib/dependencies');
var args = minimist(process.argv.slice(2), {
    boolean: ['verbose', 'help', 'ambient'],
    alias: {
        verbose: ['v'],
        ambient: ['a'],
        help: ['h']
    }
});
if (args.help) {
    console.log("\n" + config_1.PROJECT_NAME + " ls [--ambient]\n\nAliases: la, ll, list\n");
    process.exit(0);
}
var cwd = process.cwd();
var options = extend(args, { cwd: cwd });
cli_1.loader(dependencies_1.resolveTypeDependencies({ cwd: cwd, ambient: true, dev: true }), options)
    .then(function (tree) {
    var archyTree = dependencyTreeToArchy(tree, options);
    console.log(archy(archyTree));
});
function dependencyTreeToArchy(tree, options) {
    var result = {
        label: tree.name,
        nodes: []
    };
    function traverse(result, tree) {
        var nodes = result.nodes;
        if (options.ambient) {
            for (var _i = 0, _a = Object.keys(tree.ambientDependencies); _i < _a.length; _i++) {
                var name_1 = _a[_i];
                nodes.push(traverse({
                    label: name_1,
                    nodes: []
                }, tree.ambientDependencies[name_1]));
            }
        }
        else {
            for (var _b = 0, _c = Object.keys(tree.devDependencies); _b < _c.length; _b++) {
                var name_2 = _c[_b];
                nodes.push(traverse({
                    label: name_2,
                    nodes: []
                }, tree.devDependencies[name_2]));
            }
            for (var _d = 0, _e = Object.keys(tree.dependencies); _d < _e.length; _d++) {
                var name_3 = _e[_d];
                nodes.push(traverse({
                    label: name_3,
                    nodes: []
                }, tree.dependencies[name_3]));
            }
        }
        return result;
    }
    return traverse(result, tree);
}
//# sourceMappingURL=typings-list.js.map